@@ -55,3 +55,6 @@ ncard="No other swaps available"
 # Get and Print Current Swap
 swap=$(awk '/dev/ {print $1}' /proc/swaps)
 
+#Get threshold from QSettings (psb)
+psb=$(grep 'PercentForDialog*' /home/user/.config/flopswap/flopswap.conf | cut -d "=" -f 2)
+
